==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/autoccdetails_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists autoccdetails_au//
create trigger autoccdetails_au after update on autoccdetails
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     server, section, teststep, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'autoccdetails', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v),
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', NEW.formel, '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv)
  from teststepdetails, einheiten
  where NEW.TS != OLD.TS and teststepdetails.ID = NEW.teststepdetailsID and einheiten.ID = einheitID;
end//


drop trigger if exists autoccdetails_ai//
create trigger autoccdetails_ai after insert on autoccdetails
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     server, section, teststep, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'autoccdetails', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v),
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', NEW.formel, '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv)
  from teststepdetails, einheiten
  where teststepdetails.ID = NEW.teststepdetailsID and einheiten.ID=einheitID;
end//


drop trigger if exists autoccdetails_bd//
create trigger autoccdetails_bd before delete on autoccdetails
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     server, section, teststep, newvalues)
  values
    (OLD.verfahrenID, OLD.accessID, 'autoccdetails', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     showreg(OLD.server, OLD.server_v), showreg(OLD.section, OLD.section_v),
     showreg(OLD.teststep, OLD.teststep_v),
     coalesce(if(OLD.bemerkungen = @ccdetailsremark, '', concat('remark=', REPLACE(REPLACE(@ccdetailsremark, '\\', '\\\\'), '\n', '\\n'))),''));
end//

delimiter ;

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/autoccdetails_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists autoccdetails_au//
create trigger autoccdetails_au after update on autoccdetails
  for each row
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     server, section, teststep, newvalues)
  select verfahrenID, accessID, 'autoccdetails', autoccdetails.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(server, server_v), showreg(section, section_v),
    showreg(teststep, teststep_v),
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', formel, '\nremark=', REPLACE(REPLACE(bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', aktiv)
  from autoccdetails
  join teststepdetails on teststepdetails.ID = teststepdetailsID
  join einheiten on einheiten.ID = einheitID
  where autoccdetails.ID = NEW.ID and NEW.TS = autoccdetails.TS;
end//


drop trigger if exists autoccdetails_ai//
create trigger autoccdetails_ai after insert on autoccdetails
  for each row
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     server, section, teststep, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'autoccdetails', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v),
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', NEW.formel, '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv)
  from teststepdetails
  join einheiten on einheiten.ID = einheitID
  where teststepdetails.ID = NEW.teststepdetailsID;
end//


drop trigger if exists autoccdetails_bd//
create trigger autoccdetails_bd before delete on autoccdetails
  for each row
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     server, section, teststep, newvalues)
  values
    (OLD.verfahrenID, OLD.accessID, 'autoccdetails', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     showreg(OLD.server, OLD.server_v), showreg(OLD.section, OLD.section_v),
     showreg(OLD.teststep, OLD.teststep_v),
     coalesce(if(OLD.bemerkungen = @ccdetailsremark, '', concat('remark=', REPLACE(REPLACE(@ccdetailsremark, '\\', '\\\\'), '\n', '\\n'))),''));
end//

delimiter ;
